@@ -6,7 +6,7 @@ import dateutil.parser
 from quant.stats import NormalDistribution
 from quant.pricer.base import AbstractOptionPricer
 
-class BlackScholesPricer(AbstractOptionPricer):
+class EuropeanBlackScholesPricer(AbstractOptionPricer):
 
     def calcPrice(self):
         S = float(self.currentPrice)
